#!python
# -*- coding:utf-8 -*-
from __future__ import print_function
from setuptools import setup, find_packages
# import pgzero_template

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name="bhgtool",
    version='1.10.0',
    author="liuhuan",
    author_email="xiaofengkz@163.com",
    description="a template for pgzero",
    long_description=long_description,
    # long_description_content_type="text/markdown",
    license="MIT",
    url="https://github.com/zhec5hl01/python-games",
    py_modules=[''],
    install_requires=[
        "pgzero <= 1.2.1",
        "pygame <= 2.1.2"
    ],
    classifiers=[
        "Topic :: Games/Entertainment ",
        'Topic :: Games/Entertainment :: Puzzle Games',
        'Topic :: Games/Entertainment :: Board Games',
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        'Programming Language :: Python :: Implementation :: CPython',
    ],
)

